@@ -9,20 +9,20 @@
 # lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION.start_with?("3.3.") or
-    raise "ruby lib version (3.3.6) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION.start_with?("3.4.") or
+    raise "ruby lib version (3.4.1) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/3.3.0/aarch64-mingw-ucrt")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/3.4.0/aarch64-mingw-ucrt")
   # DESTDIR on make install.
   DESTDIR = TOPDIR && TOPDIR[/\A[a-z]:/i] || '' unless defined? DESTDIR
   # The hash configurations stored.
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "3"
-  CONFIG["MINOR"] = "3"
-  CONFIG["TEENY"] = "6"
-  CONFIG["PATCHLEVEL"] = "108"
+  CONFIG["MINOR"] = "4"
+  CONFIG["TEENY"] = "1"
+  CONFIG["PATCHLEVEL"] = "0"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ".exe"
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/clangarm64")
@@ -30,7 +30,7 @@ module RbConfig
   CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)"
   CONFIG["RUBY_SO_NAME"] = "aarch64-ucrt-$(RUBY_BASE_NAME)$(MAJOR)$(MINOR)0"
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-3.3.pc"
+  CONFIG["ruby_pc"] = "ruby-3.4.pc"
   CONFIG["CC_WRAPPER"] = ""
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
@@ -55,7 +55,7 @@ module RbConfig
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["rubyarchdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
-  CONFIG["ruby_version"] = "3.3.0"
+  CONFIG["ruby_version"] = "3.4.0"
   CONFIG["sitearch"] = "aarch64-ucrt"
   CONFIG["arch"] = "aarch64-mingw-ucrt"
   CONFIG["sitearchincludedir"] = "$(includedir)/$(sitearch)"
@@ -97,6 +97,7 @@ module RbConfig
   CONFIG["rubyw_install_name"] = "$(RUBYW_INSTALL_NAME)"
   CONFIG["EXTDLDFLAGS"] = "$(DEFFILE)"
   CONFIG["EXTLDFLAGS"] = ""
+  CONFIG["hardenflags"] = "-fstack-protector-strong"
   CONFIG["strict_warnflags"] = ""
   CONFIG["warnflags"] = "-Wall -Wextra -Wextra-tokens -Wdeprecated-declarations -Wdivision-by-zero -Wdiv-by-zero -Wimplicit-function-declaration -Wimplicit-int -Wpointer-arith -Wshorten-64-to-32 -Wwrite-strings -Wold-style-definition -Wmissing-noreturn -Wno-cast-function-type -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wunused-variable -Wmisleading-indentation -Wundef"
   CONFIG["debugflags"] = "-ggdb3"
@@ -112,6 +113,7 @@ module RbConfig
   CONFIG["CARGO"] = ""
   CONFIG["RUSTC"] = "no"
   CONFIG["INSTALL_STATIC_LIBRARY"] = "no"
+  CONFIG["modular_gc_dir"] = ""
   CONFIG["EXECUTABLE_EXTS"] = ".exe .com .cmd .bat"
   CONFIG["ARCHFILE"] = ""
   CONFIG["LIBRUBY_RELATIVE"] = "yes"
@@ -126,8 +128,8 @@ module RbConfig
   CONFIG["PRELOADENV"] = ""
   CONFIG["LIBPATHENV"] = "PATH"
   CONFIG["RPATHFLAG"] = ""
-  CONFIG["LIBPATHFLAG"] = " -L%s"
-  CONFIG["LINK_SO"] = ""
+  CONFIG["LIBPATHFLAG"] = "-L%s"
+  CONFIG["LINK_SO"] = "\n$(POSTLINK)"
   CONFIG["ADDITIONAL_DLDFLAGS"] = ""
   CONFIG["ENCSTATIC"] = ""
   CONFIG["EXTSTATIC"] = ""
@@ -167,10 +169,9 @@ module RbConfig
   CONFIG["LN_S"] = "cp -pR"
   CONFIG["DLLWRAP"] = "dllwrap"
   CONFIG["WINDRES"] = "windres"
-  CONFIG["ASFLAGS"] = "-mbranch-protection=pac-ret"
   CONFIG["ARFLAGS"] = "rcD "
   CONFIG["try_header"] = ""
-  CONFIG["CC_VERSION_MESSAGE"] = "clang version 19.1.4\nTarget: aarch64-w64-windows-gnu\nThread model: posix\nInstalledDir: C:/msys64/clangarm64/bin"
+  CONFIG["CC_VERSION_MESSAGE"] = "clang version 19.1.6\nTarget: aarch64-w64-windows-gnu\nThread model: posix\nInstalledDir: C:/msys64/clangarm64/bin"
   CONFIG["CC_VERSION"] = "$(CC) --version"
   CONFIG["CSRCFLAG"] = ""
   CONFIG["COUTFLAG"] = "-o "
@@ -196,6 +197,7 @@ module RbConfig
   CONFIG["CC"] = "clang"
   CONFIG["wasmoptflags"] = ""
   CONFIG["WASMOPT"] = ""
+  CONFIG["config_target"] = "aarch64-w64-mingw32"
   CONFIG["target_os"] = "mingw32"
   CONFIG["target_vendor"] = "w64"
   CONFIG["target_cpu"] = "aarch64"
@@ -217,7 +219,7 @@ module RbConfig
   CONFIG["GIT"] = "git"
   CONFIG["cxxflags"] = ""
   CONFIG["cppflags"] = ""
-  CONFIG["cflags"] = "-fdeclspec $(optflags) $(debugflags) $(warnflags)"
+  CONFIG["cflags"] = "$(hardenflags) -fdeclspec  $(optflags) $(debugflags) $(warnflags)"
   CONFIG["MAKEDIRS"] = "/usr/bin/mkdir -p"
   CONFIG["target_alias"] = ""
   CONFIG["host_alias"] = "$(target_alias)"
